@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Bulk;
-$Search::Elasticsearch::Bulk::VERSION = '1.11';
+$Search::Elasticsearch::Bulk::VERSION = '1.12';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
@@ -67,11 +67,11 @@ sub reindex {
     my ( $self, $params ) = parse_params(@_);
     my $src = $params->{source}
         or throw( 'Param', "Missing required param <source>" );
-    $src = {%$src};
 
     my $transform = $self->_doc_transformer($params);
 
     if ( ref $src eq 'HASH' ) {
+        $src = {%$src};
         my $es = delete $src->{es} || $self->es;
         my $scroll = $es->scroll_helper(
             search_type => 'scan',
@@ -88,7 +88,7 @@ sub reindex {
             if $self->verbose;
     }
 
-    while ( my @docs = $src->() ) {
+    while ( my @docs = grep {defined} $src->() ) {
         $self->index( grep {$_} map { $transform->($_) } @docs );
     }
     $self->flush;
@@ -107,7 +107,7 @@ Search::Elasticsearch::Bulk - A helper module for the Bulk API and for reindexin
 
 =head1 VERSION
 
-version 1.11
+version 1.12
 
 =head1 SYNOPSIS
 
